@@ -1,6 +1,6 @@
 #!/bin/bash
 #  This script is part of Numdiff
-#  Copyright (C)  2005-2013    Ivano Primi  <ivprimi@libero.it>    
+#  Copyright (C)  2005-2016    Ivano Primi  <ivprimi@libero.it>    
 #
 #   Copying and distribution of this file, with or without modification,
 #   are permitted in any medium without royalty provided the copyright
@@ -16,7 +16,7 @@ echo "Tester program: $DIFF"
 echo "Numdiff: $NUMDIFF"
 echo "Ndselect: $NDSELECT"
 
-TESTS="test1 test2 test4 test7 test8 test9 test10 test11 test12 test13 test14 test15 test16 test17 test18 test19 test21 test22 test24 test25 test26 test27 test28 test29 test30 test31 test32"
+TESTS="test1 test2 test4 test7 test8 test9 test10 test11 test12 test13 test14 test15 test16 test17 test18 test19 test21 test22 test24 test25 test26 test27 test28 test29 test30 test31 test32 test34"
 
 for TEST in $TESTS
 do
@@ -28,5 +28,7 @@ do
   echo -e "\nCurrent working directory: $PWD"
   RUNTEST="./run${TEST}b.sh"
   $RUNTEST $LESS $DIFF $NUMDIFF $NDSELECT
+  echo "Removing output files..."
+  rm ./output/*
+  echo "Done !"
 done
-
