@@ -1,6 +1,6 @@
 #!/bin/bash
 #  This script is part of Numdiff
-#  Copyright (C)  2005-2013    Ivano Primi  <ivprimi@libero.it>    
+#  Copyright (C)  2005-2016    Ivano Primi  <ivprimi@libero.it>    
 #
 #   Copying and distribution of this file, with or without modification,
 #   are permitted in any medium without royalty provided the copyright
@@ -45,12 +45,7 @@ for NAME in $LIST; do
     fi
 done
 
-echo "Removing output files..."
-rm ./output/*
-echo "Done !"
-
 # Common error message
 # ***  End of file "tt2" reached while trying to read line 27.
 #      File "tt1" has more lines than file "tt2",
 #      line 27 is the last one read from file "tt1"
-
