@@ -1,6 +1,6 @@
 #!/bin/bash
 #  This script is part of Numdiff
-#  Copyright (C)  2005-2009    Ivano Primi  <ivprimi@libero.it>    
+#  Copyright (C)  2005-2016    Ivano Primi  <ivprimi@libero.it>    
 #
 #   Copying and distribution of this file, with or without modification,
 #   are permitted in any medium without royalty provided the copyright
@@ -10,7 +10,7 @@ LESS=$1
 DIFF=$2
 NUMDIFF=$3
 
-$NUMDIFF -z 1:3- -z 2:3- -f 0 original modified > ./output/z3_f0om
+$NUMDIFF -z 1:3- -z 2:3- -f original modified > ./output/z3_f0om
 
 LIST="z3_f0om"
 for NAME in $LIST; do
@@ -22,7 +22,3 @@ for NAME in $LIST; do
     	echo -e "$NAME and ./output/$NAME \t are equal \t\t [ OK ]"	
     fi
 done
-
-echo "Removing output files..."
-rm ./output/*
-echo "Done !"
