@@ -1,6 +1,6 @@
 #!/bin/bash
 #  This script is part of Numdiff
-#  Copyright (C)  2005-2013    Ivano Primi  <ivprimi@libero.it>    
+#  Copyright (C)  2005-2016    Ivano Primi  <ivprimi@libero.it>    
 #
 #   Copying and distribution of this file, with or without modification,
 #   are permitted in any medium without royalty provided the copyright
@@ -22,7 +22,3 @@ for NAME in $LIST; do
     	echo -e "$NAME and ./output/$NAME \t are equal \t\t [ OK ]"
     fi
 done
-
-echo "Removing output files..."
-rm ./output/*
-echo "Done !"
