@@ -1,6 +1,6 @@
 #!/bin/bash
 #  This script is part of Numdiff
-#  Copyright (C)  2005-2013    Ivano Primi  <ivprimi@libero.it>    
+#  Copyright (C)  2005-2016    Ivano Primi  <ivprimi@libero.it>    
 #
 #   Copying and distribution of this file, with or without modification,
 #   are permitted in any medium without royalty provided the copyright
@@ -45,10 +45,6 @@ for NAME in $LIST; do
     fi
 done
 
-echo "Removing output files..."
-rm ./output/*
-echo "Done !"
-
 # Error message
 # ***  End of file "first_file" reached
 #      Likely the files "first_file" and "second_file" do not have the same number of lines !
