@@ -1,6 +1,6 @@
 #!/bin/bash
 #  This script is part of Numdiff
-#  Copyright (C)  2005-2013    Ivano Primi  <ivprimi@libero.it>    
+#  Copyright (C)  2005-2016    Ivano Primi  <ivprimi@libero.it>    
 #
 #   Copying and distribution of this file, with or without modification,
 #   are permitted in any medium without royalty provided the copyright
@@ -26,10 +26,6 @@ for NAME in $LIST; do
     fi
 done
 
-echo "Removing output files..."
-rm ./output/*
-echo "Done !"
-
 # Common error message
 # ***  End of file "file1" reached while trying to read line 7.
 #      File "file2" has more lines than file "file1",
